==> flink-agents-0.1.0-src.tgz: flink-agents-0.1.0/docs/content/_index.md <==
---
title: Apache Flink Agents Documentation 
type: docs
bookToc: false
---
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# Apache Flink Agents Documentation

{{< columns >}}
## Try Flink Agents

If you’re interested in playing around with Flink Agents, check out our [example codes]({{< ref "docs/get-started/installation" >}}). 
It provides a step by step introduction to the APIs and guides you through real applications.

<--->

## Get Help with Flink Agents

If you have questions or need support, don't hesitate to ask! We welcome you to join our Slack workspace or attend our weekly Community Sync for real-time interaction and updates.

### Slack

See the [Apache Flink website](https://flink.apache.org/what-is-flink/community/#slack) for how to join the slack workspace. We use [#flink-agents-dev](https://apache-flink.slack.com/archives/C097QF5HG8J) for developement related discussions.

### Community Sync

There is a weekly online sync. Everyone is welcome to join. Please find the schedule, agenda for the next sync, and records of previous syncs in this [github discussion page](https://github.com/apache/flink-agents/discussions/66).

{{< /columns >}}

Flink Agents is developed under the umbrella of [Apache Flink](https://flink.apache.org/).

{{< build_time >}}

==> flink-agents-0.1.1-src.tgz: flink-agents-0.1.1/docs/content/_index.md <==
---
title: Apache Flink Agents Documentation 
type: docs
bookToc: false
---
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# Apache Flink Agents Documentation

{{< columns >}}
## Try Flink Agents

If you’re interested in playing around with Flink Agents, check out our [get started documentation]({{< ref "docs/get-started/overview" >}}). 
It provides a step by step introduction on how to install Flink Agents and build agents with it.

<--->

## Get Help with Flink Agents

If you have questions or need support, don't hesitate to ask! We welcome you to join our Slack workspace or attend our weekly Community Sync for real-time interaction and updates.

### Slack

See the [Apache Flink website](https://flink.apache.org/what-is-flink/community/#slack) for how to join the slack workspace.
- [#flink-agents-user](https://apache-flink.slack.com/archives/C09KP5YUWE8) is for user-facing discussions and trouble-shootings.
- [#flink-agents-dev](https://apache-flink.slack.com/archives/C097QF5HG8J) is for developement related discussions.

### Community Sync

There is a weekly online sync. Everyone is welcome to join. Please find the schedule, agenda for the next sync, and records of previous syncs in this [github discussion page](https://github.com/apache/flink-agents/discussions/66).

{{< /columns >}}

Flink Agents is developed under the umbrella of [Apache Flink](https://flink.apache.org/).

{{< build_time >}}
